谍影重重 (豆瓣)
Description: 谍影重重电影简介和剧情介绍,谍影重重影评、图片、预告片、影讯、论坛、在线购票
Keywords: 谍影重重,The Bourne Identity,谍影重重影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.241豆瓣电影Top250

# 谍影重重 The Bourne Identity (2002)

导演: 道格·里曼
编剧: 托尼·吉尔罗伊 / 罗伯特·鲁德鲁姆 / W·布莱克·赫伦
主演: 马特·达蒙 / 弗朗卡·波滕特 / 克里斯·库珀 / 克里夫·欧文 / 朱丽娅·斯蒂尔斯 / 布莱恩·考克斯 / 阿德沃尔·阿吉纽依-艾格拜吉 / 加布里埃尔·曼 / 沃尔顿·戈金斯 / 约什·汉密尔顿 / 奥尔索·马利亚·奎利尼
类型: 动作 / 悬疑 / 惊悚
官方网站: www.thebourneidentity.com
制片国家/地区: 美国 / 德国 / 捷克
语言: 英语 / 法语 / 德语 / 荷兰语 / 意大利语
上映日期: 2002-11-21(中国大陆) / 2002-06-14(美国)
片长: 119分钟
又名: 叛谍追击(港) / 神鬼认证(台) / 伯恩的身份 / 身份的迷惑
IMDb: tt0258463
豆瓣评分
引用
8.6
403063人评价
5星
43.9%
4星
43.0%
3星
12.3%
2星
0.7%
1星
0.1%
好于 98% 动作片
好于 97% 悬疑片
想看 看过
评价:
推荐

## 谍影重重的剧情简介 · · · · · ·

杰森·伯恩（马特·达蒙 饰）在意大利被人从海上救起，他失去了记忆，除了臀部的瑞士银行帐号之外，他完全没有办法证明自己的身份。
杰森从瑞士银行找到了大量的现金，六本护照，一把枪，同时他发现自己格斗、枪械、和语言等方面的能力，他开始追查自己的身份，并且把陌生女子玛丽（弗兰卡·泼坦特 饰）也卷了进来。两人从瑞士到巴黎，一路上受到神秘杀手组织的追杀，危机重重。
杰森能否化险为夷，找到自己的真实身份？他是否有勇气面对真相？ ©豆瓣

## 谍影重重的演职员 · · · · · · ( 全部 63 )

- 道格·里曼 导演
- 马特·达蒙 饰 Bourne
- 弗朗卡·波滕特 饰 Marie
- 克里斯·库珀 饰 Conklin
- 克里夫·欧文 饰 The Professor
- 朱丽娅·斯蒂尔斯 饰 Nicolette

## 谍影重重的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片631 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  谍影重重2

  勇闯夺命岛

  碟中谍

  飓风营救

  变脸

  速度与激情5

  终结者2：审判日

  黑客帝国3：矩阵革命

  记忆碎片

  禁闭岛

我要写短评

## 谍影重重的短评 · · · · · · ( 全部 60007 条 )

热门 / 最新 / 好友

### 1235 有用 战国客 看过 2008-09-18 19:49:12

个人感觉外界评价过誉了~~

### 2636 有用 Song³ 看过 2009-04-26 01:02:01

喜欢Bourne的冷静。当Matt Damon打开银行的保险柜时，我突然发觉，世界之大，持有三样东西便可畅通无阻：金钱，身份（也可理解为地位），枪（强权）。要求自己象特工一样生活显然是很辛苦且不切实际的，然而，有些时候，特别是面对危机，试着用特工的思维方式去看待问题也许会很有效，特别是对于男生。

### 1331 有用 Jehovah 看过 2009-06-18 21:08:16

我发觉叫JB的都很厉害，是不是？James Bond, Jason Bourne

### 1189 有用 环玥 看过 2011-04-03 14:29:39

同类片教材片，唯一遗憾是女一丑。

### 403 有用 小涛 看过 2007-09-26 23:21:32

没有想像中精彩，国外版本的“我是谁”……

> 更多短评 60007条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 谍影重重的影评 · · · · · · ( 全部 379 条 )

热门 / 最新 / 好友
Jason Bourne 2007-12-05 14:31:12

## 根据影片自己总结的特工技巧【散乱，不成熟，欢迎补充！】

【Bourne系列三部中的技巧均已总结，详情参见另外两部】自我出生以来，看过的最具个人高技术、高智商含量的电影！如果还有哪部，各位认为是超出这部的，恳请赐教！ 　　简评下吧： 　　1，剧情精彩，情节设计合理，几臻圆满，充满调动观者思考积极性的元素【其中逻辑性严密程... (展开)
1751 171 203回应 收起
我是一只调羹 2007-11-25 20:56:37

## 虽然你脖子长得和大腿一样粗……

这篇影评可能有剧透

严重剧透，透一、二、三……N部，透18代祖宗。各路神仙，各种不看抬头不看标题，不看XXOO的各位，这篇评论剧透了这系列电影的每一部，所以！！！！！！有了剧透就不看片子的人士，切莫看此文，后果自负。 时隔11年的追加：这篇影评是2007年写的，本婆婆是从1996年还在用录像带... (展开)
541 92 134回应 收起
steven 2009-08-16 20:22:54

## 越是出色的男人，越不属于她

一个帅哥，而且还是看起来很忠厚可靠的那种，非常诚恳地，不惜拿一万块，就是为了搭讪；面对这么有诚意的追求，作为一个恰好挺孤寂的美女，怎么可能拒绝得了涅？ 拒绝不了的后果是什么孽？ 男人看来，是麻烦不断、飞来横祸，一段注定没有结果的感情和被一枪爆头。 女人看来，是... (展开)
401 115 65回应 收起
玄辂Hyunlu 2018-02-19 22:39:01

## 十五年后，我仍然认为这是当下最好的特工谍战片

这篇影评可能有剧透

本文已于2017年6月14日发表于[桃桃淘电影公众号]（ttfilm），如需转载请豆邮联系。 =========================================================================== 15年前的今天，《谍影重重》系列的第一部电影全面公映。作为这个系列的开山之作，它打破了包括007和碟中谍系列... (展开)
274 3 30回应 收起
行色匆匆 2006-02-04 20:18:09

## 又是一个关于“我是谁”的故事

特工的影片看得太多太多，失忆特工的影片也不在少数，所以这部影片唯一能吸引我的不过是Matt Damom。 一贯的风格，简洁有力，再加青春无敌，Matt Damon是也。当他打开银行的保险柜时，我突然发觉，世界之大，持有三样东西便可畅通无阻：金钱，身份（也可理解为地位），枪（强... (展开)
152 51 24回应 收起
沙坪坝的夏天 2010-04-02 14:58:00

## 最终兵器：Jason Bourne

这篇影评可能有剧透

本人只想从技术层面看待这部影片，之前看过很多很多的间谍片，之前也看过Bourne，但是没有像现在这样仔细仔细 从头到尾地回味，我很少会将电影看过3遍。我从2009年才开始看这部电影，三部曲一并看完，实在是很享受，这是电影的初衷，但是，我喜欢从现象，细节，任何蛛丝马迹去... (展开)
134 21 29回应 收起
一匹讲故事的马 2015-10-08 23:49:54

## 拉片

这篇影评可能有剧透

9:13 bourne在船上清醒过来，不知道自己是谁，屁股里有一个灯，提示了一个苏黎世的银行账号。登陆到瑞士大陆。 中情局说任务失败。 11:40 bourne在苏黎世闲逛，晚上睡觉遇到两个警察查身份，突然发现自己会说法语，还会格斗和枪械。慌张逃跑 13:50 介绍影片的主要目标，非洲... (展开)
81 7 6回应 收起
五号屠场 2011-07-16 19:32:44

## [关于谍影重重系列]

在碟战题材的系列电影里面，恐怕没有哪个系列可以和谍影重重叫板。 碟中谍系列呢，我觉得阿汤哥喜欢耍酷，他每次任务的完成更多地是团队合作的结果。 007系列，以前的没怎么看，最近几部，我觉得邦德的打斗太过血腥，没有美感。 所以哥一直很中意谍影重重系列。 伯恩不算帅，至... (展开)
86 6 11回应 收起
命运雕刻师 2012-06-12 23:42:47

## 静静的力量

这篇影评可能有剧透

被救上船之后，安静地和水手们一起劳动，安静地思考着自己是谁。 上岸后安静地坐在驶向瑞士的火车上。 到达瑞士后身无分文，安静地在公园长凳上睡。精彩打斗一，开始唤起心中的小宇宙。 第二天前往苏黎世银行取自己的东西，被一大叠各国纸币和手枪吓了一大跳。这时他已经被隐藏... (展开)
49 4 1回应 收起
洒小飞 2006-02-04 00:12:50

## 你是美国政府的财产，你是一件价值3000万美元的武器

很男人的一部片子，象港片中《枪火》和《暗战》一样。情节紧凑，只是比起《反恐24小时》还是可以稍微喘过来气些。背景是一个美国秘密组织训练的特工在一次行动中受伤并且失去记忆。好象特工片都爱选这个背景，很早的那部《特工狂花》也有类似的失忆情节。 伯恩在影片中... (展开)
78 24 16回应 收起

> 更多影评 379篇

添加新讨论

## 讨论区 · · · · · ·

还没看过电影 开弹幕看会被剧透吗 | 来自范吾范 | 2 回应 | 2022-11-17 18:53:58
垫尸跳楼是最大的bug | 来自羊七 | 7 回应 | 2022-11-17 18:52:02
一小时45分主角从这么高踩着人直接跳楼，约10秒内... | 来自Youngsheldon | 4 回应 | 2022-11-17 18:48:03
关于谍影重重系列主要部分及起源的个人观点及分析 | 来自夜鱼 | 2 回应 | 2022-11-12 22:35:20
和女主这条感情线应该是这部片的一个败笔了 | 来自Oakwood | 22 回应 | 2022-11-12 14:42:37

> 去这部影片的讨论区（全部134条）

## 关于《谍影重重》的问题 · · · · · · ( 全部32个 )

- 为啥心软没杀黑人？追杀他的人是什么人？后来狙击黑人的是谁派来的？ 7人回答
- 为什么CIA在伯恩失手后要杀掉伯恩？ 10人回答

> 全部32个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 芒果TV VIP免费观看
- 爱奇艺视频 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 他们是高智商玩家 (中间元素)
- {北美电影票房总排行} (荔枝超人)
- 意外结局+高智商 (鸟人与鱼)

## 谁在看这部电影 · · · · · ·

- 拨残星
  6分钟前 看过
- 凡尘
  8分钟前 看过
- momo
  11分钟前 想看

643069人看过 / 103705人想看

订阅谍影重重的评论:
feed: rss 2.0